import React from 'react'
import { get } from 'lodash'
import { Field } from 'redux-form'
import styled from 'styled-components'
import { required as requiredValidator } from 'xpub-validators'
import { ValidatedField, YesOrNo } from '@pubsweet/ui'

import { Label, Item, IconTooltip, Row, Textarea, marginHelper } from './'

const RadioWithComments = ({
  required,
  radioLabel,
  formValues,
  commentsOn,
  commentsLabel,
  radioFieldName,
  tooltipContent,
  commentsFieldName,
  ...rest
}) => (
  <Root {...rest}>
    <Row alignItems="center" justify="flex-start">
      <Item>
        <Label required={required}>{radioLabel}</Label>
        {tooltipContent && (
          <IconTooltip content={tooltipContent} interactive primary />
        )}
      </Item>
    </Row>

    <Row alignItems="center" justify="flex-start" mb={1}>
      <Field
        component={({ input }) => <YesOrNo {...input} />}
        name={radioFieldName}
      />
    </Row>

    {get(formValues, radioFieldName, '') === commentsOn && (
      <Row alignItems="center" justify="flex-start">
        <Item data-test="submission-conflicts-text" vertical>
          <Label required={required}>{commentsLabel}</Label>
          <ValidatedField
            component={Textarea}
            name={commentsFieldName}
            validate={required ? [requiredValidator] : []}
          />
        </Item>
      </Row>
    )}
  </Root>
)

export default RadioWithComments

RadioWithComments.defaultProps = {
  mb: 2,
}

// #region styles
const Root = styled.div`
  width: 100%;

  ${marginHelper};
`
// #endregion
